@@ -2,7 +2,7 @@ library(httptest)
 
 run.integration.tests <- Sys.getenv("INTEGRATION") == "TRUE"
 
-if (crunch::envOrOption("test.verify.ssl", TRUE) == FALSE) {
+if (crunch::envOrOption("test.verify.ssl", TRUE, expect_lgl = TRUE) == FALSE) {
     crunch::set_crunch_config(httr::config(ssl_verifyhost = FALSE, ssl_verifypeer = FALSE), update = TRUE)
 }
 
@@ -28,6 +28,40 @@ skip_on_local_env <- function(message) {
 
 decompress_fixtures <- function(dest = tempdir()) {
     untar(system.file("mocks.tgz", package = "crunch"), exdir = tempdir())
+
+    if (!identical(Sys.getenv("NOT_CRAN"), "true"))  return()
+    # --- If not on CRAN, try checking if the mocks are totally up-to-date
+    potential_path <- file.path(testthat::test_path("..", "..", "mocks"))
+    if (dir.exists(potential_path)) {
+        current_files <- list.files(potential_path, recursive = TRUE)
+        current_file_info <- data.frame(
+            name = current_files,
+            md5 = tools::md5sum(file.path(potential_path, current_files)),
+            stringsAsFactors = FALSE,
+            row.names = NULL
+        )
+        current_file_info <- current_file_info[order(current_file_info$name), ]
+
+        temp_files <- list.files(file.path(tempdir(), "mocks"), recursive = TRUE)
+        temp_file_info <- data.frame(
+            name = temp_files,
+            md5 = tools::md5sum(file.path(tempdir(), "mocks", temp_files)),
+            stringsAsFactors = FALSE,
+            row.names = NULL
+        )
+        temp_file_info <- temp_file_info[order(temp_file_info$name), ]
+
+        if (!isTRUE(all.equal(current_file_info, temp_file_info, check.attributes = FALSE))) {
+            warning(
+                "mocks tarball looks out of date. Run command `make compress-fixtures` to update"
+            )
+        }
+    } else {
+        warning(paste0(
+            "Could not find cubes directory so could not check if mock fixures are up to date. ",
+            "You can make sure they're updated by running `make compress-fixtures`."
+        ))
+    }
 }
 
 cubePath <- function(filename) {
@@ -119,10 +153,9 @@ test_options <- temp.options(
             "test.api",
             "http://local.crunch.io:8080/api/"
         ),
-        crunch.email = crunch::envOrOption("test.user"),
-        crunch.pw = crunch::envOrOption("test.pw"),
+        crunch.api.key = Sys.getenv("CRUNCH_TEST_API_KEY"),
         crunch.show.progress = FALSE,
-        crunch.verify_ssl = crunch::envOrOption("test.verify_ssl", TRUE),
+        crunch.verify_ssl = crunch::envOrOption("test.verify_ssl", TRUE, expect_lgl = TRUE),
         message.auth.info = TRUE
     )
 )
@@ -133,11 +166,10 @@ with_test_authentication <- function(expr) {
 
         with(test_options, {
             ## Authenticate.
-            try(suppressWarnings(suppressMessages(login())))
             on.exit({
+                httpcache::clearCache()
                 ## Delete our seen things
                 purgeEntitiesCreated()
-                logout()
             })
             ## Any time an object is created (201 Location responts), store
             ## that URL
