@@ -255,7 +255,7 @@ with_mock_crunch({
             "https://app.crunch.io/api/datasets/1/variables/gender/",
             '{"element":"shoji:entity","body":{"view":{"transform":{',
             '"insertions":[{"anchor":3,"name":"Male+Female","function"',
-            ':"subtotal","args":[1,2]}]}}}}'
+            ':"subtotal","args":[1,2],"id":1}]}}}}'
         )
     })
 
@@ -271,7 +271,7 @@ with_mock_crunch({
             "https://app.crunch.io/api/datasets/1/variables/gender/",
             '{"element":"shoji:entity","body":{"view":{"transform":{',
             '"insertions":[{"anchor":3,"name":"Male+Female","function"',
-            ':"subtotal","args":[1,2],"kwargs":{"positive":[1,2]}}]}}}}'
+            ':"subtotal","args":[1,2],"kwargs":{"positive":[1,2]},"id":1}]}}}}'
         )
     })
 
@@ -287,6 +287,48 @@ with_mock_crunch({
         )
     })
 
+    test_that("Can add a MR insertion via `Insertion()`", {
+        expect_PATCH(
+            subtotals(ds$mymrset) <- list(
+                Insertion(
+                    anchor = "top",
+                    `function` = "any_selected",
+                    name = "s1 or s2",
+                    id = 1,
+                    kwargs = list(
+                        variable = "mymrset",
+                        subvariable_ids = c("subvar1", "subvar2")
+                    )
+                )
+            ),
+            "https://app.crunch.io/api/datasets/1/variables/mymrset/",
+            '{"view":{"transform":{"insertions":[{"anchor":"top","function":"any_selected",',
+            '"name":"s1 or s2","id":1,"kwargs":{"variable":"mymrset","subvariable_ids":',
+            '["subvar1","subvar2"]}}]}}}'
+        )
+    })
+
+    test_that("Can add a MR insertion via `Insertion()` via transforms()<-", {
+        expect_PATCH(
+            transforms(ds$mymrset) <- Transforms(
+                insertions = list(Insertion(
+                    anchor = "top",
+                    `function` = "any_selected",
+                    name = "s1 or s2",
+                    id = 1,
+                    kwargs = list(
+                        variable = "mymrset",
+                        subvariable_ids = c("subvar1", "subvar2")
+                    )
+                ))
+            ),
+            "https://app.crunch.io/api/datasets/1/variables/mymrset/",
+            '{"element":"shoji:entity","body":{"view":{"transform":{"insertions"',
+            ':[{"anchor":"top","function":"any_selected","name":"s1 or s2",',
+            '"id":1,"kwargs":{"variable":"mymrset","subvariable_ids":["subvar1",',
+            '"subvar2"]}}]}}}}'
+        )
+    })
 
 
     test_that("Can delete transform", {
